% Run script for bilinear finite elements on a quadrilateral mesh 

clear all
close all

% Initialize constants
NREFS = 4;                 % Number of red refinement steps
T = 0.1;                   % Final time
F_HANDLE   = @(x,varargin) zeros(size(x,1),1);                 % Right hand side source term
U0_HANDLE  = @(x,varargin) sin(pi*x(:,1)).*sin(pi*x(:,2));     % Initial data
UEX_HANDLE = @(x,t,varargin) exp(-2*pi^2*t)*sin(pi*x(:,1)).*sin(pi*x(:,2));  % Exact solution
      
% Initialize mesh
Mesh = load_Mesh('Coord_Square.dat','Elem_Square.dat');
Mesh = add_Edges(Mesh);
Loc = get_BdEdges(Mesh);
Mesh.BdFlags = zeros(size(Mesh.Edges,1),1);
Mesh.BdFlags(Loc) = -1;
Mesh.ElemFlag = zeros(size(Mesh.Elements,1),1);

% Initialize quadrature rules
QuadRule = TProd(gauleg(0,1,4));

% Do NREFS uniform refinement steps
L2Err = zeros(1,NREFS);
nDofs = zeros(1,NREFS);
  
for j = 1:NREFS
      
    % refine mesh
    Mesh = refine_REG(Mesh);

    % Number of time steps

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%% YOU WILL HAVE TO MODIFY THIS CONSTANT %%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    NSTEPS = 50;

    % Compute matrices
    M = assemMat_BFE(Mesh,@MASS_BFE,QuadRule);

    % Compute initial data
    u_old = assemLoad_BFE(Mesh,QuadRule,U0_HANDLE);
    u_old = M\u_old;

    % Run timestepping
    u_new = Parb_Evl_BFE(Mesh, u_old, F_HANDLE, T, NSTEPS);
   
    % Compute L2 error  at time T  
    L2Err(j) = L2Err_BFE(Mesh,u_new,QuadRule,UEX_HANDLE,T);
    nDofs(j) = size(Mesh.Coordinates,1);

end
 
% Plot out discretization error against number of dofs
  
%%%%% YOUR CODE HERE %%%%%
